#ifndef VIDEOLAUNCHER_H
#define VIDEOLAUNCHER_H

#include <QObject>

class QUrl;

class VideoLauncher : public QObject
{
    Q_OBJECT

public:
    explicit VideoLauncher(QObject *parent = 0);
    static VideoLauncher* instance();
        
public slots:
    static void launchVideo(const QUrl &url);

private:
    static VideoLauncher *self;
};

#endif // VIDEOLAUNCHER_H
